summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmtextedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmtextedit.h')
-rw-r--r--kpovmodeler/pmtextedit.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kpovmodeler/pmtextedit.h b/kpovmodeler/pmtextedit.h
index 132adc5e..96510257 100644
--- a/kpovmodeler/pmtextedit.h
+++ b/kpovmodeler/pmtextedit.h
@@ -38,12 +38,13 @@ class TQPushButton;
class PMTextEdit : public PMSolidObjectEdit
{
Q_OBJECT
+ TQ_OBJECT
typedef PMSolidObjectEdit Base;
public:
/**
* Creates a PMTextEdit with parent and name
*/
- PMTextEdit( TQWidget* parent, const char* name = 0 );
+ PMTextEdit( TQWidget* tqparent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -38,12 +38,13 @@ class TQPushButton;
public:
/**
- * Creates a PMTextEdit with parent and name
+ * Creates a PMTextEdit with tqparent and name
*/